==> agnostos-0.9.7.tar.gz: agnostos/agnostos_docroot/view_audit.pl <==
#!/usr/bin/perl -w 

# Copyright (C) 2000 Julian T. J. Midgley <jtjm@xenoclast.org>
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
# A copy of version 2 of the GNU General Public License may be found
# in the file "LICENCE" in the original Agnostos installation driectory.


use taskman_lib;
use strict;
use CGI;

my $query = new CGI;
my $dbh   = dbserver_connect('agnostos');
my $todoid = $query -> param('todoid');
my ($comment, $date, $dbq, $td);
my %users  = fetch_ents( 'user',       $dbh);
my %groups = fetch_ents( 'workgroup',  $dbh);
my %depts  = fetch_ents( 'department', $dbh);
my $tablehead="#efea9e";         # Background colour of headings
my $tableheadcol="#ffffff";      # Text colour of headings

print html_header("Audit Trail", $query);

$dbq = $dbh -> prepare ("SELECT title, status, priority, userid, groupid, depid, date
                         FROM todo, assigned
                         WHERE todo.todoid=assigned.todoid
                         AND todo.todoid=$todoid");
$dbq -> execute;

my ($title, $status, $priority, $userid, $groupid, $depid, $itemdate) = $dbq -> fetchrow_array;

if (defined $itemdate && $itemdate =~ /(\d+)-(\d+)-(\d+)/) {
    $itemdate = "$3-$2-$1";
}
else {
    $itemdate = "";
}

print "<h2>Audit Trail</h2>\n";
$td = "<td bgcolor=$tablehead>";
print "<table><tr>$td<b>ID</b>$td<b>Task</b>\n";
print "$td<b>Priority</b>\n";
print "$td<b>Status</b>\n";
print "$td<b>User</b>$td<b>Group</b>$td<b>Department</b>\n";
print "$td<b>Due Date</b>\n";
$td = "<td bgcolor=#dfd7c9>";
print "<tr>$td$todoid$td$title$td$priority$td$status".
      "$td$users{$userid}$td$groups{$groupid}$td$depts{$depid}$td$itemdate</tr></table>\n";

$dbq -> finish;
print "<p>\n";

$dbq = $dbh -> prepare ("SELECT comment, date 
                         FROM audit
                         WHERE todoid = $todoid
                         ORDER BY date");
my $numrows = $dbq -> execute;
if ( $numrows > 0 ) {
    print "<table border=1><tr><td align=center><b>Date</b></td><td align=center><b>Comment</b></td></tr>\n";
    while ( ($comment,$date) = $dbq -> fetchrow_array ) {
	$comment =~ s/\n/<br>/g;
	print "<tr><td>$date</td><td>$comment</td></tr>\n";
    }
    print "</table>";
}
else 
{
    print "<h2>No audit data available</h2>\n";
}
$dbq -> finish;

print html_footer;

$dbh -> disconnect;

==> agnostos-0.9.10.tar.gz: agnostos/agnostos_docroot/view_audit.pl <==
#!/usr/bin/perl -w 

# Copyright (C) 2000 Julian T. J. Midgley <jtjm@xenoclast.org>
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
# A copy of version 2 of the GNU General Public License may be found
# in the file "LICENCE" in the original Agnostos installation driectory.


use taskman_lib;
use strict;
use CGI;
use CGI::Carp qw(fatalsToBrowser);


my $query = new CGI;
my %config = get_config();
my $dbh   = dbserver_connect(\%config);
my $todoid = $query -> param('todoid');
my ($comment, $date, $dbq, $td);
my %users  = fetch_ents( 'user',       $dbh);
my %groups = fetch_ents( 'workgroup',  $dbh);
my %depts  = fetch_ents( 'department', $dbh);
my $tablehead="#efea9e";         # Background colour of headings
my $tableheadcol="#ffffff";      # Text colour of headings
my ($sep,@date_format) = parse_date_format(\%config);

print html_header("Audit Trail", $query);

$dbq = $dbh -> prepare ("SELECT title, status, priority, userid, groupid, depid, date, completed_date
                         FROM todo, assigned
                         WHERE todo.todoid=assigned.todoid
                         AND todo.todoid=$todoid");
$dbq -> execute;

my ($title, $status, $priority, $userid, $groupid, $depid, $itemdate, $completed_date) 
   = $dbq -> fetchrow_array;

if (defined $itemdate && $itemdate =~ /(\d+)-(\d+)-(\d+)/) {
    $itemdate = format_text_date($3,$2,$1,$sep,@date_format);
}
else {
    $itemdate = "";
}

$completed_date = "" unless (defined $completed_date);

print "<h2>Audit Trail</h2>\n";
$td = "<td bgcolor=$tablehead>";
print "<table><tr>$td<b>ID</b>$td<b>Task</b>\n";
print "$td<b>Priority</b>\n";
print "$td<b>Status</b>\n";
print "$td<b>User</b>$td<b>Group</b>$td<b>Department</b>\n";
print "$td<b>Due Date</b>$td<b>Mtime</b>\n";
$td = "<td bgcolor=#dfd7c9>";

print "<tr>$td$todoid".
      "$td$title".
      "$td$priority".
      "$td$status".
      "$td$users{$userid}".
      "$td$groups{$groupid}".
      "$td$depts{$depid}".
      "$td$itemdate".
      "$td$completed_date</tr></table>\n";

$dbq -> finish;
print "<p>\n";

$dbq = $dbh -> prepare ("SELECT comment, date 
                         FROM audit
                         WHERE todoid = $todoid
                         ORDER BY date");
my $numrows = $dbq -> execute;
if ( $numrows > 0 ) {
    print "<table border=1><tr><td align=center><b>Date</b></td><td align=center><b>Comment</b></td></tr>\n";
    while ( ($comment,$date) = $dbq -> fetchrow_array ) {
	$comment =~ s/\n/<br>/g;
	print "<tr><td>$date</td><td>$comment</td></tr>\n";
    }
    print "</table>";
}
else 
{
    print "<h2>No audit data available</h2>\n";
}
$dbq -> finish;

print html_footer;

$dbh -> disconnect;
